@@ -2,7 +2,7 @@
 """
 A Gtk+ application for keeping track of time.
 
-$Id: gtimelog.py 90 2008-04-22 17:43:53Z mg $
+$Id: gtimelog.py 105 2008-04-22 21:23:08Z mg $
 """
 
 import re
@@ -252,6 +252,8 @@ class TimeWindow(object):
             if skip_first:
                 skip_first = False
                 continue
+            if '***' in entry:
+                continue
             if '**' in entry:
                 entries = slack
             else:
@@ -803,12 +805,12 @@ class TrayIcon(object):
 class MainWindow(object):
     """Main application window."""
 
+    # Initial view mode
     chronological = True
-    footer_mark = None
+    show_tasks = True
 
-    # Try to prevent timer routines mucking with the buffer while we're
-    # mucking with the buffer.  Not sure if it is necessary.
-    lock = False
+    # URL to use for Help -> Online Documentation
+    help_url = "http://mg.pov.lt/gtimelog"
 
     def __init__(self, timelog, settings, tasks):
         """Create the main window."""
@@ -816,9 +818,24 @@ class MainWindow(object):
         self.settings = settings
         self.tasks = tasks
         self.last_tick = None
+        self.footer_mark = None
+        # Try to prevent timer routines mucking with the buffer while we're
+        # mucking with the buffer.  Not sure if it is necessary.
+        self.lock = False
         self.entry_watchers = []
+        self._init_ui()
+
+    def _init_ui(self):
+        """Initialize the user interface."""
         tree = gtk.glade.XML(ui_file)
+        # Set initial state of menu items *before* we hook up signals
+        chronological_menu_item = tree.get_widget("chronological")
+        chronological_menu_item.set_active(self.chronological)
+        show_task_pane_item = tree.get_widget("show_task_pane")
+        show_task_pane_item.set_active(self.show_tasks)
+        # Now hook up signals
         tree.signal_autoconnect(self)
+        # Store references to UI elements we're going to need later
         self.tray_icon_popup_menu = tree.get_widget("tray_icon_popup_menu")
         self.tray_show = tree.get_widget("tray_show")
         self.tray_hide = tree.get_widget("tray_hide")
@@ -833,10 +850,13 @@ class MainWindow(object):
         self.main_window.connect("delete_event", self.delete_event)
         self.log_view = tree.get_widget("log_view")
         self.set_up_log_view_columns()
+        self.task_pane = tree.get_widget("task_list_pane")
+        if not self.show_tasks:
+            self.task_pane.hide()
         self.task_pane_info_label = tree.get_widget("task_pane_info_label")
-        tasks.loading_callback = self.task_list_loading
-        tasks.loaded_callback = self.task_list_loaded
-        tasks.error_callback = self.task_list_error
+        self.tasks.loading_callback = self.task_list_loading
+        self.tasks.loaded_callback = self.task_list_loaded
+        self.tasks.error_callback = self.task_list_error
         self.task_list = tree.get_widget("task_list")
         self.task_store = gtk.TreeStore(str, str)
         self.task_list.set_model(self.task_store)
@@ -1075,6 +1095,11 @@ class MainWindow(object):
         """Help -> About selected"""
         self.about_dialog.show()
 
+    def on_online_help_activate(self, widget):
+        """Help -> Online Documentation selected"""
+        import webbrowser
+        webbrowser.open(self.help_url)
+
     def on_chronological_activate(self, widget):
         """View -> Chronological"""
         self.chronological = True
@@ -1220,6 +1245,13 @@ class MainWindow(object):
         self.populate_log()
         self.tick(True)
 
+    def on_show_task_pane_toggled(self, event):
+        """View -> Tasks"""
+        if self.task_pane.get_property("visible"):
+            self.task_pane.hide()
+        else:
+            self.task_pane.show()
+
     def task_list_row_activated(self, treeview, path, view_column):
         """A task was selected in the task pane -- put it to the entry."""
         model = treeview.get_model()
